@@ -18,6 +18,7 @@ from vinca.generators import generate, GENERATORS_DICT
 # feed them this explicitly á la FILTER
 
 TODAY = datetime.date.today()
+DAY = datetime.timedelta(days=1)
 
 PIPE_IN = not sys.stdin.isatty()
 PIPE_OUT = not sys.stdout.isatty()
@@ -27,6 +28,7 @@ vinca_path = Path(__file__).parent
 cards_path = Path.home() / 'cards'
 ALL_CARDS = [Card(int(id.name)) for id in cards_path.iterdir()] # TODO: load cards otf
 ALL_TAGS = [tag for card in ALL_CARDS for tag in card.tags] # TODO: cache
+VERSION = 115
 
 # ARGUMENT PARSING
 parser = argparse.ArgumentParser(usage=argparse.SUPPRESS, epilog='Use -h to see help for any command. Visit the manual for usage examples.')
@@ -36,7 +38,7 @@ def card_type(arg):
 	return Card(id)
 def date_type(s):
 	if s[s[0] in ['+','-']:].isdigit():
-		return TODAY + int(arg) * DAY
+		return TODAY + int(s) * DAY
 	try:
 		return datetime.datetime.strptime(s, '%Y-%m-%d').date()
 	except ValueError:
@@ -346,12 +348,14 @@ def imp(args):
 		copytree(card_path, cards_path / str(new_id))
 
 
+
 for alias, generator in GENERATORS_DICT.items():
 	p = subparsers.add_parser(generator, aliases=[alias], help='')
 	p.add_argument('-t','--default_tags',nargs='*',default=[])
 	p.set_defaults(func = generate, generator = generator)
 
 # parse the command line arguments
+parser.add_argument('-V','--version',action='version',version=str(VERSION))
 parser.set_defaults(cards = [], func = lambda args: parser.print_help(), review_date = TODAY, scrollback = False, card = None)
 # simplifiy the help message
 parser._action_groups[0].title = 'commands'
